@@ -1,3 +1,19 @@
+# Copyright (C) 2020  Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include is.R
 #' @include capture.R
 
@@ -42,7 +58,7 @@ setClass(
     if(!identical(slotNames(object), .unitizer.global.settings.names)) {
       paste0(
         "Invalid global object, slots must be ",
-        deparse(.unitizer.global.settings.names, width=500)
+        deparse(.unitizer.global.settings.names, width.cutoff=500L)
       )
     TRUE
 } )
@@ -273,7 +289,7 @@ get_namespace_data <- function() {
       ver <- ns[[".__NAMESPACE__."]][["spec"]]["version"]
       if(is.null(ver)) ver <- ""
       if(is.null(loc)) loc <- ""
-      list(name=x, lib.loc=loc, version=ver)
+      list(names=x, lib.loc=loc, version=ver)
     },
     simplify=FALSE
   )
