@@ -1,3 +1,19 @@
+# Copyright (C) 2020  Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include exec.R
 
 NULL
@@ -111,7 +127,16 @@ unitizer_prompt <- function(
   )
   repeat {
     prompt.txt <- sprintf("%s> ", "unitizer")
-    val <- tryCatch(faux_prompt(prompt.txt), simpleError=function(e) e)
+
+    old.opt <- options(warn=1)
+    on.exit(options(old.opt))
+    val <- tryCatch(
+      faux_prompt(prompt.txt),
+      simpleError=function(e) e
+    )
+    on.exit(NULL)
+    options(old.opt)
+
     if(inherits(val, "simpleError")) {
       cond.chr <- as.character(val)
       cat(cond.chr, file=stderr())
@@ -159,8 +184,10 @@ unitizer_prompt <- function(
 
     # store / record history
 
-    if(!is.null(hist.con) && length(val) == 1L)
-      history_write(hist.con, deparse(val[[1L]]))
+    if(!is.null(hist.con) && length(val) == 1L) {
+      dval <- deparse(val[[1L]])
+      history_write(hist.con, dval)
+    }
     # error or no user input, re-prompt user
     if(res$aborted || !length(val)) {
       cat("\n")
@@ -366,7 +393,7 @@ exit_fun <- function(y, env, valid.vals) {
 read_line <- function(prompt="") {
   stopifnot(is.chr1(prompt))
   if(is.null(.global$prompt.vals)) {
-    readline(prompt)
+    readline(prompt)  # nocov can't test this in non-interactive
   } else if(!is.character(.global$prompt.vals)) {
     stop( # nocov start
       "Internal Error: internal object `.global$prompt.vals` has unexpected ",
